@@ -73,8 +73,7 @@ JSON::writeArrayClose(Pipeline* p, bool first, size_t depth)
 }
 
 void
-JSON::writeDictionaryKey(
-    Pipeline* p, bool& first, std::string const& key, size_t depth)
+JSON::writeDictionaryKey(Pipeline* p, bool& first, std::string const& key, size_t depth)
 {
     writeNext(p, first, depth);
     *p << std::string("\"") + key + "\": ";
@@ -82,19 +81,14 @@ JSON::writeDictionaryKey(
 
 void
 JSON::writeDictionaryItem(
-    Pipeline* p,
-    bool& first,
-    std::string const& key,
-    JSON const& value,
-    size_t depth)
+    Pipeline* p, bool& first, std::string const& key, JSON const& value, size_t depth)
 {
     writeDictionaryKey(p, first, key, depth);
     value.write(p, depth);
 }
 
 void
-JSON::writeArrayItem(
-    Pipeline* p, bool& first, JSON const& element, size_t depth)
+JSON::writeArrayItem(Pipeline* p, bool& first, JSON const& element, size_t depth)
 {
     writeNext(p, first, depth);
     element.write(p, depth);
@@ -197,10 +191,10 @@ JSON::JSON_blob::write(Pipeline* p, size_t) const
 void
 JSON::write(Pipeline* p, size_t depth) const
 {
-    if (nullptr == this->m->value) {
+    if (nullptr == m->value) {
         *p << "null";
     } else {
-        this->m->value->write(p, depth);
+        m->value->write(p, depth);
     }
 }
 
@@ -282,22 +276,19 @@ JSON::makeDictionary()
 JSON
 JSON::addDictionaryMember(std::string const& key, JSON const& val)
 {
-    if (auto* obj = dynamic_cast<JSON_dictionary*>(this->m->value.get())) {
-        return obj->members[encode_string(key)] =
-                   val.m->value ? val : makeNull();
+    if (auto* obj = dynamic_cast<JSON_dictionary*>(m->value.get())) {
+        return obj->members[encode_string(key)] = val.m->value ? val : makeNull();
     } else {
-        throw std::runtime_error(
-            "JSON::addDictionaryMember called on non-dictionary");
+        throw std::runtime_error("JSON::addDictionaryMember called on non-dictionary");
     }
 }
 
 bool
 JSON::checkDictionaryKeySeen(std::string const& key)
 {
-    JSON_dictionary* obj = dynamic_cast<JSON_dictionary*>(this->m->value.get());
+    auto* obj = dynamic_cast<JSON_dictionary*>(m->value.get());
     if (nullptr == obj) {
-        throw std::logic_error(
-            "JSON::checkDictionaryKey called on non-dictionary");
+        throw std::logic_error("JSON::checkDictionaryKey called on non-dictionary");
     }
     if (obj->parsed_keys.count(key)) {
         return true;
@@ -315,7 +306,7 @@ JSON::makeArray()
 JSON
 JSON::addArrayElement(JSON const& val)
 {
-    JSON_array* arr = dynamic_cast<JSON_array*>(this->m->value.get());
+    auto* arr = dynamic_cast<JSON_array*>(m->value.get());
     if (nullptr == arr) {
         throw std::runtime_error("JSON::addArrayElement called on non-array");
     }
@@ -385,7 +376,7 @@ bool
 JSON::getString(std::string& utf8) const
 {
     if (m->value->type_code == vt_string) {
-        auto v = dynamic_cast<JSON_string const*>(this->m->value.get());
+        auto v = dynamic_cast<JSON_string const*>(m->value.get());
         utf8 = v->utf8;
         return true;
     }
@@ -396,7 +387,7 @@ bool
 JSON::getNumber(std::string& value) const
 {
     if (m->value->type_code == vt_number) {
-        auto v = dynamic_cast<JSON_number const*>(this->m->value.get());
+        auto v = dynamic_cast<JSON_number const*>(m->value.get());
         value = v->encoded;
         return true;
     }
@@ -407,7 +398,7 @@ bool
 JSON::getBool(bool& value) const
 {
     if (m->value->type_code == vt_bool) {
-        auto v = dynamic_cast<JSON_bool const*>(this->m->value.get());
+        auto v = dynamic_cast<JSON_bool const*>(m->value.get());
         value = v->value;
         return true;
     }
@@ -421,10 +412,9 @@ JSON::isNull() const
 }
 
 bool
-JSON::forEachDictItem(
-    std::function<void(std::string const& key, JSON value)> fn) const
+JSON::forEachDictItem(std::function<void(std::string const& key, JSON value)> fn) const
 {
-    auto v = dynamic_cast<JSON_dictionary const*>(this->m->value.get());
+    auto v = dynamic_cast<JSON_dictionary const*>(m->value.get());
     if (v == nullptr) {
         return false;
     }
@@ -437,7 +427,7 @@ JSON::forEachDictItem(
 bool
 JSON::forEachArrayItem(std::function<void(JSON value)> fn) const
 {
-    auto v = dynamic_cast<JSON_array const*>(this->m->value.get());
+    auto v = dynamic_cast<JSON_array const*>(m->value.get());
     if (v == nullptr) {
         return false;
     }
@@ -450,16 +440,13 @@ JSON::forEachArrayItem(std::function<void(JSON value)> fn) const
 bool
 JSON::checkSchema(JSON schema, std::list<std::string>& errors)
 {
-    return checkSchemaInternal(
-        this->m->value.get(), schema.m->value.get(), 0, errors, "");
+    return checkSchemaInternal(m->value.get(), schema.m->value.get(), 0, errors, "");
 }
 
 bool
-JSON::checkSchema(
-    JSON schema, unsigned long flags, std::list<std::string>& errors)
+JSON::checkSchema(JSON schema, unsigned long flags, std::list<std::string>& errors)
 {
-    return checkSchemaInternal(
-        this->m->value.get(), schema.m->value.get(), flags, errors, "");
+    return checkSchemaInternal(m->value.get(), schema.m->value.get(), flags, errors, "");
 }
 
 bool
@@ -470,13 +457,13 @@ JSON::checkSchemaInternal(
     std::list<std::string>& errors,
     std::string prefix)
 {
-    JSON_array* this_arr = dynamic_cast<JSON_array*>(this_v);
-    JSON_dictionary* this_dict = dynamic_cast<JSON_dictionary*>(this_v);
+    auto* this_arr = dynamic_cast<JSON_array*>(this_v);
+    auto* this_dict = dynamic_cast<JSON_dictionary*>(this_v);
 
-    JSON_array* sch_arr = dynamic_cast<JSON_array*>(sch_v);
-    JSON_dictionary* sch_dict = dynamic_cast<JSON_dictionary*>(sch_v);
+    auto* sch_arr = dynamic_cast<JSON_array*>(sch_v);
+    auto* sch_dict = dynamic_cast<JSON_dictionary*>(sch_v);
 
-    JSON_string* sch_str = dynamic_cast<JSON_string*>(sch_v);
+    auto* sch_str = dynamic_cast<JSON_string*>(sch_v);
 
     std::string err_prefix;
     if (prefix.empty()) {
@@ -495,8 +482,8 @@ JSON::checkSchemaInternal(
         auto members = sch_dict->members;
         std::string key;
         if ((members.size() == 1) &&
-            ((key = members.begin()->first, key.length() > 2) &&
-             (key.at(0) == '<') && (key.at(key.length() - 1) == '>'))) {
+            ((key = members.begin()->first, key.length() > 2) && (key.at(0) == '<') &&
+             (key.at(key.length() - 1) == '>'))) {
             pattern_key = key;
         }
     }
@@ -565,17 +552,12 @@ JSON::checkSchemaInternal(
             } else {
                 QTC::TC("libtests", "JSON schema array for single item");
                 checkSchemaInternal(
-                    this_v,
-                    sch_arr->elements.at(0).m->value.get(),
-                    flags,
-                    errors,
-                    prefix);
+                    this_v, sch_arr->elements.at(0).m->value.get(), flags, errors, prefix);
             }
         } else if (!this_arr || (this_arr->elements.size() != n_elements)) {
             QTC::TC("libtests", "JSON schema array length mismatch");
             errors.push_back(
-                err_prefix + " is supposed to be an array of length " +
-                std::to_string(n_elements));
+                err_prefix + " is supposed to be an array of length " + std::to_string(n_elements));
             return false;
         } else {
             // A multi-element array in the schema must correspond to
@@ -595,8 +577,7 @@ JSON::checkSchemaInternal(
         }
     } else if (!sch_str) {
         QTC::TC("libtests", "JSON schema other type");
-        errors.push_back(
-            err_prefix + " schema value is not dictionary, array, or string");
+        errors.push_back(err_prefix + " schema value is not dictionary, array, or string");
         return false;
     }
 
@@ -736,8 +717,7 @@ JSONParser::handle_u_code(
                 " surrogate");
         }
         high_offset = 0;
-        codepoint =
-            0x10000U + ((high_surrogate & 0x3FFU) << 10U) + (codepoint & 0x3FF);
+        codepoint = 0x10000U + ((high_surrogate & 0x3FFU) << 10U) + (codepoint & 0x3FF);
         result += QUtil::toUTF8(codepoint);
     } else {
         result += QUtil::toUTF8(codepoint);
@@ -760,8 +740,8 @@ JSONParser::tokenError()
     } else if (lex_state == ls_alpha) {
         QTC::TC("libtests", "JSON parse keyword bad character");
         throw std::runtime_error(
-            "JSON: offset " + std::to_string(offset) +
-            ": keyword: unexpected character " + std::string(p, 1));
+            "JSON: offset " + std::to_string(offset) + ": keyword: unexpected character " +
+            std::string(p, 1));
     } else if (lex_state == ls_string) {
         QTC::TC("libtests", "JSON parse control char in string");
         throw std::runtime_error(
@@ -775,8 +755,7 @@ JSONParser::tokenError()
     }
 
     if (*p == '.') {
-        if (lex_state == ls_number || lex_state == ls_number_e ||
-            lex_state == ls_number_e_sign) {
+        if (lex_state == ls_number || lex_state == ls_number_e || lex_state == ls_number_e_sign) {
             QTC::TC("libtests", "JSON parse point after e");
             throw std::runtime_error(
                 "JSON: offset " + std::to_string(offset) +
@@ -790,24 +769,21 @@ JSONParser::tokenError()
     } else if (*p == 'e' || *p == 'E') {
         QTC::TC("libtests", "JSON parse duplicate e");
         throw std::runtime_error(
-            "JSON: offset " + std::to_string(offset) +
-            ": numeric literal: e already seen");
+            "JSON: offset " + std::to_string(offset) + ": numeric literal: e already seen");
     } else if ((*p == '+') || (*p == '-')) {
         QTC::TC("libtests", "JSON parse unexpected sign");
         throw std::runtime_error(
-            "JSON: offset " + std::to_string(offset) +
-            ": numeric literal: unexpected sign");
+            "JSON: offset " + std::to_string(offset) + ": numeric literal: unexpected sign");
     } else if (QUtil::is_space(*p) || strchr("{}[]:,", *p)) {
         QTC::TC("libtests", "JSON parse incomplete number");
         throw std::runtime_error(
-            "JSON: offset " + std::to_string(offset) +
-            ": numeric literal: incomplete number");
+            "JSON: offset " + std::to_string(offset) + ": numeric literal: incomplete number");
 
     } else {
         QTC::TC("libtests", "JSON parse numeric bad character");
         throw std::runtime_error(
-            "JSON: offset " + std::to_string(offset) +
-            ": numeric literal: unexpected character " + std::string(p, 1));
+            "JSON: offset " + std::to_string(offset) + ": numeric literal: unexpected character " +
+            std::string(p, 1));
     }
     throw std::logic_error("JSON::tokenError : unhandled error");
 }
@@ -884,8 +860,7 @@ JSONParser::getToken()
             } else {
                 QTC::TC("libtests", "JSON parse null character");
                 throw std::runtime_error(
-                    "JSON: control or null character at offset " +
-                    std::to_string(offset));
+                    "JSON: control or null character at offset " + std::to_string(offset));
             }
         } else if (*p == ',') {
             if (lex_state == ls_top) {
@@ -968,8 +943,8 @@ JSONParser::getToken()
                 } else {
                     QTC::TC("libtests", "JSON parse bad character");
                     throw std::runtime_error(
-                        "JSON: offset " + std::to_string(offset) +
-                        ": unexpected character " + std::string(p, 1));
+                        "JSON: offset " + std::to_string(offset) + ": unexpected character " +
+                        std::string(p, 1));
                 }
                 break;
 
@@ -994,8 +969,7 @@ JSONParser::getToken()
                 } else {
                     QTC::TC("libtests", "JSON parse leading zero");
                     throw std::runtime_error(
-                        "JSON: offset " + std::to_string(offset) +
-                        ": number with leading zero");
+                        "JSON: offset " + std::to_string(offset) + ": number with leading zero");
                 }
                 break;
 
@@ -1121,30 +1095,20 @@ JSONParser::getToken()
 
             case ls_u4:
                 using ui = unsigned int;
-                if ('0' <= *p && *p <= '9') {
-                    u_value = 16 * u_value + (ui(*p) - ui('0'));
-                } else if ('a' <= *p && *p <= 'f') {
-                    u_value = 16 * u_value + (10 + ui(*p) - ui('a'));
-                } else if ('A' <= *p && *p <= 'F') {
-                    u_value = 16 * u_value + (10 + ui(*p) - ui('A'));
+                if (ui val = ui(QUtil::hex_decode_char(*p)); val < 16) {
+                    u_value = 16 * u_value + val;
                 } else {
                     tokenError();
                 }
                 if (++u_count == 4) {
-                    handle_u_code(
-                        u_value,
-                        offset - 5,
-                        high_surrogate,
-                        high_offset,
-                        token);
+                    handle_u_code(u_value, offset - 5, high_surrogate, high_offset, token);
                     lex_state = ls_string;
                 }
                 ignore();
                 break;
 
             default:
-                throw std::logic_error(
-                    "JSONParser::getToken : trying to handle delimiter state");
+                throw std::logic_error("JSONParser::getToken : trying to handle delimiter state");
             }
         }
     }
@@ -1209,19 +1173,16 @@ JSONParser::handleToken()
         if (parser_state != ps_dict_after_key) {
             QTC::TC("libtests", "JSON parse unexpected :");
             throw std::runtime_error(
-                "JSON: offset " + std::to_string(offset) +
-                ": unexpected colon");
+                "JSON: offset " + std::to_string(offset) + ": unexpected colon");
         }
         parser_state = ps_dict_after_colon;
         return;
 
     case ls_comma:
-        if (!((parser_state == ps_dict_after_item) ||
-              (parser_state == ps_array_after_item))) {
+        if (!((parser_state == ps_dict_after_item) || (parser_state == ps_array_after_item))) {
             QTC::TC("libtests", "JSON parse unexpected ,");
             throw std::runtime_error(
-                "JSON: offset " + std::to_string(offset) +
-                ": unexpected comma");
+                "JSON: offset " + std::to_string(offset) + ": unexpected comma");
         }
         if (parser_state == ps_dict_after_item) {
             parser_state = ps_dict_after_comma;
@@ -1234,12 +1195,10 @@ JSONParser::handleToken()
         return;
 
     case ls_end_array:
-        if (!(parser_state == ps_array_begin ||
-              parser_state == ps_array_after_item)) {
+        if (!(parser_state == ps_array_begin || parser_state == ps_array_after_item)) {
             QTC::TC("libtests", "JSON parse unexpected ]");
             throw std::runtime_error(
-                "JSON: offset " + std::to_string(offset) +
-                ": unexpected array end delimiter");
+                "JSON: offset " + std::to_string(offset) + ": unexpected array end delimiter");
         }
         parser_state = stack.back().state;
         tos.setEnd(offset);
@@ -1252,12 +1211,10 @@ JSONParser::handleToken()
         return;
 
     case ls_end_dict:
-        if (!((parser_state == ps_dict_begin) ||
-              (parser_state == ps_dict_after_item))) {
+        if (!((parser_state == ps_dict_begin) || (parser_state == ps_dict_after_item))) {
             QTC::TC("libtests", "JSON parse unexpected }");
             throw std::runtime_error(
-                "JSON: offset " + std::to_string(offset) +
-                ": unexpected dictionary end delimiter");
+                "JSON: offset " + std::to_string(offset) + ": unexpected dictionary end delimiter");
         }
         parser_state = stack.back().state;
         tos.setEnd(offset);
@@ -1283,14 +1240,12 @@ JSONParser::handleToken()
         } else {
             QTC::TC("libtests", "JSON parse invalid keyword");
             throw std::runtime_error(
-                "JSON: offset " + std::to_string(offset) +
-                ": invalid keyword " + token);
+                "JSON: offset " + std::to_string(offset) + ": invalid keyword " + token);
         }
         break;
 
     case ls_string:
-        if (parser_state == ps_dict_begin ||
-            parser_state == ps_dict_after_comma) {
+        if (parser_state == ps_dict_begin || parser_state == ps_dict_after_comma) {
             dict_key = token;
             dict_key_offset = token_start;
             parser_state = ps_dict_after_key;
@@ -1301,8 +1256,7 @@ JSONParser::handleToken()
         break;
 
     default:
-        throw std::logic_error(
-            "JSONParser::handleToken : non-terminal lexer state encountered");
+        throw std::logic_error("JSONParser::handleToken : non-terminal lexer state encountered");
         break;
     }
 
@@ -1314,16 +1268,14 @@ JSONParser::handleToken()
     case ps_dict_after_comma:
         QTC::TC("libtests", "JSON parse string as dict key");
         throw std::runtime_error(
-            "JSON: offset " + std::to_string(offset) +
-            ": expect string as dictionary key");
+            "JSON: offset " + std::to_string(offset) + ": expect string as dictionary key");
         break;
 
     case ps_dict_after_colon:
         if (tos.checkDictionaryKeySeen(dict_key)) {
             QTC::TC("libtests", "JSON parse duplicate key");
             throw std::runtime_error(
-                "JSON: offset " + std::to_string(dict_key_offset) +
-                ": duplicated dictionary key");
+                "JSON: offset " + std::to_string(dict_key_offset) + ": duplicated dictionary key");
         }
         if (!reactor || !reactor->dictionaryItem(dict_key, item)) {
             tos.addDictionaryMember(dict_key, item);
@@ -1350,8 +1302,7 @@ JSONParser::handleToken()
 
     case ps_dict_after_key:
         QTC::TC("libtests", "JSON parse expected colon");
-        throw std::runtime_error(
-            "JSON: offset " + std::to_string(offset) + ": expected ':'");
+        throw std::runtime_error("JSON: offset " + std::to_string(offset) + ": expected ':'");
         break;
 
     case ps_dict_after_item:
@@ -1367,8 +1318,7 @@ JSONParser::handleToken()
         break;
 
     case ps_done:
-        throw std::logic_error(
-            "JSONParser::handleToken: unexpected parser state");
+        throw std::logic_error("JSONParser::handleToken: unexpected parser state");
     }
 
     if (item.isDictionary() || item.isArray()) {
@@ -1391,8 +1341,7 @@ JSONParser::handleToken()
 
         if (stack.size() > 500) {
             throw std::runtime_error(
-                "JSON: offset " + std::to_string(offset) +
-                ": maximum object depth exceeded");
+                "JSON: offset " + std::to_string(offset) + ": maximum object depth exceeded");
         }
     }
 }
@@ -1433,23 +1382,23 @@ JSON::parse(std::string const& s)
 void
 JSON::setStart(qpdf_offset_t start)
 {
-    this->m->start = start;
+    m->start = start;
 }
 
 void
 JSON::setEnd(qpdf_offset_t end)
 {
-    this->m->end = end;
+    m->end = end;
 }
 
 qpdf_offset_t
 JSON::getStart() const
 {
-    return this->m->start;
+    return m->start;
 }
 
 qpdf_offset_t
 JSON::getEnd() const
 {
-    return this->m->end;
+    return m->end;
 }
