@@ -1,9 +1,8 @@
 #include <qpdf/Pl_ASCIIHexDecoder.hh>
 
 #include <qpdf/QTC.hh>
-#include <ctype.h>
+#include <cctype>
 #include <stdexcept>
-#include <string.h>
 
 Pl_ASCIIHexDecoder::Pl_ASCIIHexDecoder(char const* identifier, Pipeline* next) :
     Pipeline(identifier, next),
@@ -77,12 +76,9 @@ Pl_ASCIIHexDecoder::flush()
             b[i] = this->inbuf[i] - '0';
         }
     }
-    unsigned char ch = static_cast<unsigned char>((b[0] << 4) + b[1]);
+    auto ch = static_cast<unsigned char>((b[0] << 4) + b[1]);
 
-    QTC::TC(
-        "libtests",
-        "Pl_ASCIIHexDecoder partial flush",
-        (this->pos == 2) ? 0 : 1);
+    QTC::TC("libtests", "Pl_ASCIIHexDecoder partial flush", (this->pos == 2) ? 0 : 1);
     // Reset before calling getNext()->write in case that throws an
     // exception.
     this->pos = 0;
