@@ -1,7 +1,7 @@
 #include <qpdf/Pl_Flate.hh>
 
-#include <limits.h>
-#include <string.h>
+#include <climits>
+#include <cstring>
 #include <zlib.h>
 
 #include <qpdf/QIntC.hh>
@@ -54,10 +54,7 @@ Pl_Flate::Members::~Members()
 }
 
 Pl_Flate::Pl_Flate(
-    char const* identifier,
-    Pipeline* next,
-    action_e action,
-    unsigned int out_bufsize_int) :
+    char const* identifier, Pipeline* next, action_e action, unsigned int out_bufsize_int) :
     Pipeline(identifier, next),
     m(new Members(QIntC::to_size(out_bufsize_int), action))
 {
@@ -72,24 +69,23 @@ Pl_Flate::~Pl_Flate()
 void
 Pl_Flate::setWarnCallback(std::function<void(char const*, int)> callback)
 {
-    this->m->callback = callback;
+    m->callback = callback;
 }
 
 void
 Pl_Flate::warn(char const* msg, int code)
 {
-    if (this->m->callback != nullptr) {
-        this->m->callback(msg, code);
+    if (m->callback != nullptr) {
+        m->callback(msg, code);
     }
 }
 
 void
 Pl_Flate::write(unsigned char const* data, size_t len)
 {
-    if (this->m->outbuf == nullptr) {
+    if (m->outbuf == nullptr) {
         throw std::logic_error(
-            this->identifier +
-            ": Pl_Flate: write() called after finish() called");
+            this->identifier + ": Pl_Flate: write() called after finish() called");
     }
 
     // Write in chunks in case len is too big to fit in an int.
@@ -99,10 +95,7 @@ Pl_Flate::write(unsigned char const* data, size_t len)
     unsigned char const* buf = data;
     while (bytes_left > 0) {
         size_t bytes = (bytes_left >= max_bytes ? max_bytes : bytes_left);
-        handleData(
-            buf,
-            bytes,
-            (this->m->action == a_inflate ? Z_SYNC_FLUSH : Z_NO_FLUSH));
+        handleData(buf, bytes, (m->action == a_inflate ? Z_SYNC_FLUSH : Z_NO_FLUSH));
         bytes_left -= bytes;
         buf += bytes;
     }
@@ -115,48 +108,44 @@ Pl_Flate::handleData(unsigned char const* data, size_t len, int flush)
         throw std::runtime_error("Pl_Flate: zlib doesn't support data"
                                  " blocks larger than int");
     }
-    z_stream& zstream = *(static_cast<z_stream*>(this->m->zdata));
+    z_stream& zstream = *(static_cast<z_stream*>(m->zdata));
     // zlib is known not to modify the data pointed to by next_in but
     // doesn't declare the field value const unless compiled to do so.
     zstream.next_in = const_cast<unsigned char*>(data);
     zstream.avail_in = QIntC::to_uint(len);
 
-    if (!this->m->initialized) {
+    if (!m->initialized) {
         int err = Z_OK;
 
         // deflateInit and inflateInit are macros that use old-style
         // casts.
-#if ( \
-    (defined(__GNUC__) && ((__GNUC__ * 100) + __GNUC_MINOR__) >= 406) || \
-    defined(__clang__))
+#if ((defined(__GNUC__) && ((__GNUC__ * 100) + __GNUC_MINOR__) >= 406) || defined(__clang__))
 # pragma GCC diagnostic push
 # pragma GCC diagnostic ignored "-Wold-style-cast"
 #endif
-        if (this->m->action == a_deflate) {
+        if (m->action == a_deflate) {
             err = deflateInit(&zstream, compression_level);
         } else {
             err = inflateInit(&zstream);
         }
-#if ( \
-    (defined(__GNUC__) && ((__GNUC__ * 100) + __GNUC_MINOR__) >= 406) || \
-    defined(__clang__))
+#if ((defined(__GNUC__) && ((__GNUC__ * 100) + __GNUC_MINOR__) >= 406) || defined(__clang__))
 # pragma GCC diagnostic pop
 #endif
 
         checkError("Init", err);
-        this->m->initialized = true;
+        m->initialized = true;
     }
 
     int err = Z_OK;
 
     bool done = false;
     while (!done) {
-        if (this->m->action == a_deflate) {
+        if (m->action == a_deflate) {
             err = deflate(&zstream, flush);
         } else {
             err = inflate(&zstream, flush);
         }
-        if ((this->m->action == a_inflate) && (err != Z_OK) && zstream.msg &&
+        if ((m->action == a_inflate) && (err != Z_OK) && zstream.msg &&
             (strcmp(zstream.msg, "incorrect data check") == 0)) {
             // Other PDF readers ignore this specific error. Combining
             // this with Z_SYNC_FLUSH enables qpdf to handle some
@@ -173,8 +162,7 @@ Pl_Flate::handleData(unsigned char const* data, size_t len, int flush)
             // least one in qpdf's test suite). In some cases, we want
             // to know about this, because it indicates incorrect
             // compression, so call a callback if provided.
-            this->warn(
-                "input stream is complete but output may still be valid", err);
+            this->warn("input stream is complete but output may still be valid", err);
             done = true;
             break;
 
@@ -190,12 +178,11 @@ Pl_Flate::handleData(unsigned char const* data, size_t len, int flush)
                     // needed, so we're done for now.
                     done = true;
                 }
-                uLong ready =
-                    QIntC::to_ulong(this->m->out_bufsize - zstream.avail_out);
+                uLong ready = QIntC::to_ulong(m->out_bufsize - zstream.avail_out);
                 if (ready > 0) {
-                    this->getNext()->write(this->m->outbuf.get(), ready);
-                    zstream.next_out = this->m->outbuf.get();
-                    zstream.avail_out = QIntC::to_uint(this->m->out_bufsize);
+                    this->getNext()->write(m->outbuf.get(), ready);
+                    zstream.next_out = m->outbuf.get();
+                    zstream.avail_out = QIntC::to_uint(m->out_bufsize);
                 }
             }
             break;
@@ -211,23 +198,23 @@ void
 Pl_Flate::finish()
 {
     try {
-        if (this->m->outbuf.get()) {
-            if (this->m->initialized) {
-                z_stream& zstream = *(static_cast<z_stream*>(this->m->zdata));
+        if (m->outbuf.get()) {
+            if (m->initialized) {
+                z_stream& zstream = *(static_cast<z_stream*>(m->zdata));
                 unsigned char buf[1];
                 buf[0] = '\0';
                 handleData(buf, 0, Z_FINISH);
                 int err = Z_OK;
-                if (this->m->action == a_deflate) {
+                if (m->action == a_deflate) {
                     err = deflateEnd(&zstream);
                 } else {
                     err = inflateEnd(&zstream);
                 }
-                this->m->initialized = false;
+                m->initialized = false;
                 checkError("End", err);
             }
 
-            this->m->outbuf = nullptr;
+            m->outbuf = nullptr;
         }
     } catch (std::exception& e) {
         try {
@@ -249,12 +236,10 @@ Pl_Flate::setCompressionLevel(int level)
 void
 Pl_Flate::checkError(char const* prefix, int error_code)
 {
-    z_stream& zstream = *(static_cast<z_stream*>(this->m->zdata));
+    z_stream& zstream = *(static_cast<z_stream*>(m->zdata));
     if (error_code != Z_OK) {
-        char const* action_str =
-            (this->m->action == a_deflate ? "deflate" : "inflate");
-        std::string msg =
-            this->identifier + ": " + action_str + ": " + prefix + ": ";
+        char const* action_str = (m->action == a_deflate ? "deflate" : "inflate");
+        std::string msg = this->identifier + ": " + action_str + ": " + prefix + ": ";
 
         if (zstream.msg) {
             msg += zstream.msg;
@@ -285,8 +270,7 @@ Pl_Flate::checkError(char const* prefix, int error_code)
                 break;
 
             default:
-                msg += std::string("zlib unknown error (") +
-                    std::to_string(error_code) + ")";
+                msg += std::string("zlib unknown error (") + std::to_string(error_code) + ")";
                 break;
             }
         }
