@@ -8,18 +8,18 @@ namespace
     class NumberTreeDetails: public NNTreeDetails
     {
       public:
-        virtual std::string const&
+        std::string const&
         itemsKey() const override
         {
             static std::string k("/Nums");
             return k;
         }
-        virtual bool
+        bool
         keyValid(QPDFObjectHandle oh) const override
         {
             return oh.isInteger();
         }
-        virtual int
+        int
         compareKeys(QPDFObjectHandle a, QPDFObjectHandle b) const override
         {
             if (!(keyValid(a) && keyValid(b))) {
@@ -42,8 +42,7 @@ QPDFNumberTreeObjectHelper::~QPDFNumberTreeObjectHelper()
     // #745.
 }
 
-QPDFNumberTreeObjectHelper::Members::Members(
-    QPDFObjectHandle& oh, QPDF& q, bool auto_repair) :
+QPDFNumberTreeObjectHelper::Members::Members(QPDFObjectHandle& oh, QPDF& q, bool auto_repair) :
     impl(std::make_shared<NNTreeImpl>(number_tree_details, q, oh, auto_repair))
 {
 }
@@ -62,8 +61,7 @@ QPDFNumberTreeObjectHelper::newEmpty(QPDF& qpdf, bool auto_repair)
         qpdf.makeIndirectObject("<< /Nums [] >>"_qpdf), qpdf, auto_repair);
 }
 
-QPDFNumberTreeObjectHelper::iterator::iterator(
-    std::shared_ptr<NNTreeIterator> const& i) :
+QPDFNumberTreeObjectHelper::iterator::iterator(std::shared_ptr<NNTreeIterator> const& i) :
     impl(i)
 {
 }
@@ -124,8 +122,7 @@ QPDFNumberTreeObjectHelper::iterator::operator==(iterator const& other) const
 }
 
 void
-QPDFNumberTreeObjectHelper::iterator::insertAfter(
-    numtree_number key, QPDFObjectHandle value)
+QPDFNumberTreeObjectHelper::iterator::insertAfter(numtree_number key, QPDFObjectHandle value)
 {
     impl->insertAfter(QPDFObjectHandle::newInteger(key), value);
     updateIValue();
@@ -141,41 +138,39 @@ QPDFNumberTreeObjectHelper::iterator::remove()
 QPDFNumberTreeObjectHelper::iterator
 QPDFNumberTreeObjectHelper::begin() const
 {
-    return iterator(std::make_shared<NNTreeIterator>(this->m->impl->begin()));
+    return iterator(std::make_shared<NNTreeIterator>(m->impl->begin()));
 }
 
 QPDFNumberTreeObjectHelper::iterator
 QPDFNumberTreeObjectHelper::end() const
 {
-    return iterator(std::make_shared<NNTreeIterator>(this->m->impl->end()));
+    return iterator(std::make_shared<NNTreeIterator>(m->impl->end()));
 }
 
 QPDFNumberTreeObjectHelper::iterator
 QPDFNumberTreeObjectHelper::last() const
 {
-    return iterator(std::make_shared<NNTreeIterator>(this->m->impl->last()));
+    return iterator(std::make_shared<NNTreeIterator>(m->impl->last()));
 }
 
 QPDFNumberTreeObjectHelper::iterator
-QPDFNumberTreeObjectHelper::find(
-    numtree_number key, bool return_prev_if_not_found)
+QPDFNumberTreeObjectHelper::find(numtree_number key, bool return_prev_if_not_found)
 {
-    auto i = this->m->impl->find(
-        QPDFObjectHandle::newInteger(key), return_prev_if_not_found);
+    auto i = m->impl->find(QPDFObjectHandle::newInteger(key), return_prev_if_not_found);
     return iterator(std::make_shared<NNTreeIterator>(i));
 }
 
 QPDFNumberTreeObjectHelper::iterator
 QPDFNumberTreeObjectHelper::insert(numtree_number key, QPDFObjectHandle value)
 {
-    auto i = this->m->impl->insert(QPDFObjectHandle::newInteger(key), value);
+    auto i = m->impl->insert(QPDFObjectHandle::newInteger(key), value);
     return iterator(std::make_shared<NNTreeIterator>(i));
 }
 
 bool
 QPDFNumberTreeObjectHelper::remove(numtree_number key, QPDFObjectHandle* value)
 {
-    return this->m->impl->remove(QPDFObjectHandle::newInteger(key), value);
+    return m->impl->remove(QPDFObjectHandle::newInteger(key), value);
 }
 
 QPDFNumberTreeObjectHelper::numtree_number
@@ -233,7 +228,7 @@ QPDFNumberTreeObjectHelper::findObjectAtOrBelow(
 void
 QPDFNumberTreeObjectHelper::setSplitThreshold(int t)
 {
-    this->m->impl->setSplitThreshold(t);
+    m->impl->setSplitThreshold(t);
 }
 
 std::map<QPDFNumberTreeObjectHelper::numtree_number, QPDFObjectHandle>
